import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { FollowService } from '../../service/core/follow.service';
import { CDTO_follow, CVO_follow, FVO_follow, QDTO_follow, QVO_follow, UDTO_follow, UVAO_follow } from '../../interface/core/follow.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['关注'])
@Controller('/follow')
export class FollowController extends BaseController {
  @Inject()
  service: FollowService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_follow })
  async create(@Body() data: CDTO_follow) {
    const dbData = await this.service.create(data);
    const result = new CVO_follow(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_follow })
  async query(@Query() filter: QDTO_follow, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_follow(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_follow })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_follow(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_follow })
  async update(@Param('id') id: string, @Body() body: UDTO_follow) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
