import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { OpinionService } from '../../service/core/opinion.service';
import { CDTO_opinion, CVO_opinion, FVO_opinion, QDTO_opinion, QVO_opinion, UDTO_opinion, UVAO_opinion } from '../../interface/core/opinion.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['意见反馈'])
@Controller('/opinion')
export class OpinionController extends BaseController {
  @Inject()
  service: OpinionService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_opinion })
  async create(@Body() data: CDTO_opinion) {
    const dbData = await this.service.create(data);
    const result = new CVO_opinion(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_opinion })
  async query(@Query() filter: QDTO_opinion, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const arr = await this.service.list(list);
    const data = [];
    for (const i of arr) {
      const newData = new QVO_opinion(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_opinion })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const info = await this.service.detail(data);
    const result = new FVO_opinion(info);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_opinion })
  async update(@Param('id') id: string, @Body() body: UDTO_opinion) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
