import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { StudentService } from '../../service/core/student.service';
import { CDTO_student, CVO_student, FVO_student, QDTO_student, QVO_student, UDTO_student, UVAO_student } from '../../interface/core/student.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { UtilService } from '../../service/util.service';
@ApiTags(['家长或学生'])
@Controller('/student')
export class StudentController extends BaseController {
  @Inject()
  service: StudentService;

  @Inject()
  utilService: UtilService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_student })
  async create(@Body() data: CDTO_student) {
    await this.utilService.createUserBefor(data, 'Student');
    const dbData = await this.service.create(data);
    const result = new CVO_student(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_student })
  async query(@Query() filter: QDTO_student, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_student(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_student })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_student(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_student })
  async update(@Param('id') id: string, @Body() body: UDTO_student) {
    const result = await this.service.updateOne(id, body);
    await this.utilService.updateUserAfter(id, body, 'Student');
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
