import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TeacherService } from '../../service/core/teacher.service';
import { CDTO_teacher, CVO_teacher, FVO_teacher, QDTO_teacher, QVO_teacher, UDTO_teacher, UVAO_teacher } from '../../interface/core/teacher.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { UtilService } from '../../service/util.service';
@ApiTags(['老师'])
@Controller('/teacher')
export class TeacherController extends BaseController {
  @Inject()
  service: TeacherService;

  @Inject()
  utilService: UtilService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_teacher })
  async create(@Body() data: CDTO_teacher) {
    await this.utilService.createUserBefor(data, 'Teacher');
    const dbData = await this.service.create(data);
    const result = new CVO_teacher(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_teacher })
  async query(@Query() filter: QDTO_teacher, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_teacher(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_teacher })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_teacher(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_teacher })
  async update(@Param('id') id: string, @Body() body: UDTO_teacher) {
    const result = await this.service.updateOne(id, body);
    await this.utilService.updateUserAfter(id, body, 'Teacher');
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
